@@ -39,10 +39,11 @@ class TestWritersModule(unittest.TestCase):
         """Conversion to image."""
         # 1D
         from satpy.writers import to_image
-        p = xr.DataArray(np.arange(25), dims=['y'])
-        self.assertRaises(ValueError, to_image, p)
+        p = xr.DataArray(np.arange(25), dims=["y"])
+        with pytest.raises(ValueError, match="Need at least a 2D array to make an image."):
+            to_image(p)
 
-    @mock.patch('satpy.writers.XRImage')
+    @mock.patch("satpy.writers.XRImage")
     def test_to_image_2d(self, mock_geoimage):
         """Conversion to image."""
         from satpy.writers import to_image
@@ -51,35 +52,35 @@ class TestWritersModule(unittest.TestCase):
         data = np.arange(25).reshape((5, 5))
         p = xr.DataArray(data, attrs=dict(mode="L", fill_value=0,
                                           palette=[0, 1, 2, 3, 4, 5]),
-                         dims=['y', 'x'])
+                         dims=["y", "x"])
         to_image(p)
 
         np.testing.assert_array_equal(
             data, mock_geoimage.call_args[0][0].values)
         mock_geoimage.reset_mock()
 
-    @mock.patch('satpy.writers.XRImage')
+    @mock.patch("satpy.writers.XRImage")
     def test_to_image_3d(self, mock_geoimage):
         """Conversion to image."""
         # 3D
         from satpy.writers import to_image
         data = np.arange(75).reshape((3, 5, 5))
-        p = xr.DataArray(data, dims=['bands', 'y', 'x'])
-        p['bands'] = ['R', 'G', 'B']
+        p = xr.DataArray(data, dims=["bands", "y", "x"])
+        p["bands"] = ["R", "G", "B"]
         to_image(p)
         np.testing.assert_array_equal(data[0], mock_geoimage.call_args[0][0][0])
         np.testing.assert_array_equal(data[1], mock_geoimage.call_args[0][0][1])
         np.testing.assert_array_equal(data[2], mock_geoimage.call_args[0][0][2])
 
-    @mock.patch('satpy.writers.get_enhanced_image')
+    @mock.patch("satpy.writers.get_enhanced_image")
     def test_show(self, mock_get_image):
         """Check showing."""
         from satpy.writers import show
 
         data = np.arange(25).reshape((5, 5))
-        p = xr.DataArray(data, dims=['y', 'x'])
+        p = xr.DataArray(data, dims=["y", "x"])
         show(p)
-        self.assertTrue(mock_get_image.return_value.show.called)
+        assert mock_get_image.return_value.show.called
 
 
 class TestEnhancer(unittest.TestCase):
@@ -89,13 +90,13 @@ class TestEnhancer(unittest.TestCase):
         """Test Enhancer init with no arguments passed."""
         from satpy.writers import Enhancer
         e = Enhancer()
-        self.assertIsNotNone(e.enhancement_tree)
+        assert e.enhancement_tree is not None
 
     def test_basic_init_no_enh(self):
         """Test Enhancer init requesting no enhancements."""
         from satpy.writers import Enhancer
         e = Enhancer(enhancement_config_file=False)
-        self.assertIsNone(e.enhancement_tree)
+        assert e.enhancement_tree is None
 
     def test_basic_init_provided_enh(self):
         """Test Enhancer init with string enhancement configs."""
@@ -108,13 +109,13 @@ class TestEnhancer(unittest.TestCase):
       method: !!python/name:satpy.enhancements.stretch
       kwargs: {stretch: linear}
 """])
-        self.assertIsNotNone(e.enhancement_tree)
+        assert e.enhancement_tree is not None
 
     def test_init_nonexistent_enh_file(self):
         """Test Enhancer init with a nonexistent enhancement configuration file."""
         from satpy.writers import Enhancer
-        self.assertRaises(
-            ValueError, Enhancer, enhancement_config_file="is_not_a_valid_filename_?.yaml")
+        with pytest.raises(ValueError, match="YAML file doesn't exist or string is not YAML dict:.*"):
+            Enhancer(enhancement_config_file="is_not_a_valid_filename_?.yaml")
 
 
 class _BaseCustomEnhancementConfigTests:
@@ -128,7 +129,7 @@ class _BaseCustomEnhancementConfigTests:
             base_dir = os.path.dirname(fn)
             if base_dir:
                 os.makedirs(base_dir, exist_ok=True)
-            with open(fn, 'w') as f:
+            with open(fn, "w") as f:
                 f.write(content)
 
         # create fake test image writer
@@ -136,7 +137,7 @@ class _BaseCustomEnhancementConfigTests:
 
         class CustomImageWriter(ImageWriter):
             def __init__(self, **kwargs):
-                super(CustomImageWriter, self).__init__(name='test', config_files=[], **kwargs)
+                super(CustomImageWriter, self).__init__(name="test", config_files=[], **kwargs)
                 self.img = None
 
             def save_image(self, img, **kwargs):
@@ -148,7 +149,7 @@ class _BaseCustomEnhancementConfigTests:
         """Remove fake user configurations."""
         for fn, _content in cls.TEST_CONFIGS.items():
             base_dir = os.path.dirname(fn)
-            if base_dir not in ['.', ''] and os.path.isdir(base_dir):
+            if base_dir not in [".", ""] and os.path.isdir(base_dir):
                 shutil.rmtree(base_dir)
             elif os.path.isfile(fn):
                 os.remove(fn)
@@ -157,8 +158,8 @@ class _BaseCustomEnhancementConfigTests:
 class TestComplexSensorEnhancerConfigs(_BaseCustomEnhancementConfigTests):
     """Test enhancement configs that use or expect multiple sensors."""
 
-    ENH_FN = 'test_sensor1.yaml'
-    ENH_FN2 = 'test_sensor2.yaml'
+    ENH_FN = "test_sensor1.yaml"
+    ENH_FN2 = "test_sensor2.yaml"
 
     TEST_CONFIGS = {
         ENH_FN: """
@@ -203,11 +204,11 @@ enhancements:
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
                        attrs={
-                           'name': 'test1',
-                           'sensor': {'test_sensor2', 'test_sensor1'},
-                           'mode': 'L'
+                           "name": "test1",
+                           "sensor": {"test_sensor2", "test_sensor1"},
+                           "mode": "L"
                        },
-                       dims=['y', 'x'])
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         img = get_enhanced_image(ds, enhance=e)
@@ -226,11 +227,11 @@ enhancements:
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
                        attrs={
-                           'name': 'my_comp',
-                           'sensor': {'test_sensor2', 'test_sensor1'},
-                           'mode': 'L'
+                           "name": "my_comp",
+                           "sensor": {"test_sensor2", "test_sensor1"},
+                           "mode": "L"
                        },
-                       dims=['y', 'x'])
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         img = get_enhanced_image(ds, enhance=e)
@@ -248,8 +249,8 @@ enhancements:
 
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(name=["I", "am", "invalid"], sensor='test_sensor2', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name=["I", "am", "invalid"], sensor="test_sensor2", mode="L"),
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         with pytest.raises(KeyError, match="No .* found for None"):
@@ -259,11 +260,11 @@ enhancements:
 class TestEnhancerUserConfigs(_BaseCustomEnhancementConfigTests):
     """Test `Enhancer` functionality when user's custom configurations are present."""
 
-    ENH_FN = 'test_sensor.yaml'
-    ENH_ENH_FN = os.path.join('enhancements', ENH_FN)
-    ENH_FN2 = 'test_sensor2.yaml'
-    ENH_ENH_FN2 = os.path.join('enhancements', ENH_FN2)
-    ENH_FN3 = 'test_empty.yaml'
+    ENH_FN = "test_sensor.yaml"
+    ENH_ENH_FN = os.path.join("enhancements", ENH_FN)
+    ENH_FN2 = "test_sensor2.yaml"
+    ENH_ENH_FN2 = os.path.join("enhancements", ENH_FN2)
+    ENH_FN3 = "test_empty.yaml"
 
     TEST_CONFIGS = {
         ENH_FN: """
@@ -303,8 +304,8 @@ enhancements:
 
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(sensor='test_empty', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(sensor="test_empty", mode="L"),
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         get_enhanced_image(ds, enhance=e)
@@ -317,8 +318,8 @@ enhancements:
 
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(sensor='test_sensor2', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(sensor="test_sensor2", mode="L"),
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         get_enhanced_image(ds, enhance=e)
@@ -332,8 +333,8 @@ enhancements:
 
         from satpy.writers import get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(name='test1', sensor='test_sensor', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name="test1", sensor="test_sensor", mode="L"),
+                       dims=["y", "x"])
         img = get_enhanced_image(ds, enhance=False)
         np.testing.assert_allclose(img.data.data.compute().squeeze(), ds.data)
 
@@ -341,8 +342,8 @@ enhancements:
         """Test turning off enhancements with writer."""
         from xarray import DataArray
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(name='test1', sensor='test_sensor', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name="test1", sensor="test_sensor", mode="L"),
+                       dims=["y", "x"])
         writer = self.CustomImageWriter(enhance=False)
         writer.save_datasets((ds,), compute=False)
         img = writer.img
@@ -354,8 +355,8 @@ enhancements:
 
         from satpy.writers import Enhancer
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(name='test1', sensor='test_sensor', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name="test1", sensor="test_sensor", mode="L"),
+                       dims=["y", "x"])
         enhance = Enhancer()
         writer = self.CustomImageWriter(enhance=enhance)
         writer.save_datasets((ds,), compute=False)
@@ -368,8 +369,8 @@ enhancements:
 
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(name='test1', sensor='test_sensor', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name="test1", sensor="test_sensor", mode="L"),
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         img = get_enhanced_image(ds, enhance=e)
@@ -380,8 +381,8 @@ enhancements:
                                        1.)
 
         ds = DataArray(da.arange(1, 11., chunks=5).reshape((2, 5)),
-                       attrs=dict(name='test1', sensor='test_sensor', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name="test1", sensor="test_sensor", mode="L"),
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         img = get_enhanced_image(ds, enhance=e)
@@ -396,9 +397,9 @@ enhancements:
 
         from satpy.writers import Enhancer, get_enhanced_image
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
-                       attrs=dict(name='test1', units='kelvin',
-                                  sensor='test_sensor', mode='L'),
-                       dims=['y', 'x'])
+                       attrs=dict(name="test1", units="kelvin",
+                                  sensor="test_sensor", mode="L"),
+                       dims=["y", "x"])
         e = Enhancer()
         assert e.enhancement_tree is not None
         img = get_enhanced_image(ds, enhance=e)
@@ -411,7 +412,7 @@ enhancements:
 class TestReaderEnhancerConfigs(_BaseCustomEnhancementConfigTests):
     """Test enhancement configs that use reader name."""
 
-    ENH_FN = 'test_sensor1.yaml'
+    ENH_FN = "test_sensor1.yaml"
 
     # NOTE: The sections are ordered in a special way so that if 'reader' key
     #   isn't provided that we'll get the section we didn't want and all tests
@@ -452,11 +453,11 @@ enhancements:
         from xarray import DataArray
         ds = DataArray(np.arange(1, 11.).reshape((2, 5)),
                        attrs={
-                           'name': 'test1',
-                           'sensor': 'test_sensor1',
-                           'mode': 'L',
+                           "name": "test1",
+                           "sensor": "test_sensor1",
+                           "mode": "L",
                        },
-                       dims=['y', 'x'])
+                       dims=["y", "x"])
         return ds
 
     def _get_enhanced_image(self, data_arr):
@@ -512,33 +513,31 @@ class TestYAMLFiles(unittest.TestCase):
         class IgnoreLoader(yaml.SafeLoader):
 
             def _ignore_all_tags(self, tag_suffix, node):
-                return tag_suffix + ' ' + node.value
-        IgnoreLoader.add_multi_constructor('', IgnoreLoader._ignore_all_tags)
+                return tag_suffix + " " + node.value
+        IgnoreLoader.add_multi_constructor("", IgnoreLoader._ignore_all_tags)
 
         from satpy._config import glob_config
         from satpy.writers import read_writer_config
-        for writer_config in glob_config('writers/*.yaml'):
+        for writer_config in glob_config("writers/*.yaml"):
             writer_fn = os.path.basename(writer_config)
             writer_fn_name = os.path.splitext(writer_fn)[0]
             writer_info = read_writer_config([writer_config],
                                              loader=IgnoreLoader)
-            self.assertEqual(writer_fn_name, writer_info['name'],
-                             "Writer YAML filename doesn't match writer "
-                             "name in the YAML file.")
+            assert writer_fn_name == writer_info["name"]
 
     def test_available_writers(self):
         """Test the 'available_writers' function."""
         from satpy import available_writers
         writer_names = available_writers()
-        self.assertGreater(len(writer_names), 0)
-        self.assertIsInstance(writer_names[0], str)
-        self.assertIn('geotiff', writer_names)
+        assert len(writer_names) > 0
+        assert isinstance(writer_names[0], str)
+        assert "geotiff" in writer_names
 
         writer_infos = available_writers(as_dict=True)
-        self.assertEqual(len(writer_names), len(writer_infos))
-        self.assertIsInstance(writer_infos[0], dict)
+        assert len(writer_names) == len(writer_infos)
+        assert isinstance(writer_infos[0], dict)
         for writer_info in writer_infos:
-            self.assertIn('name', writer_info)
+            assert "name" in writer_info
 
 
 class TestComputeWriterResults(unittest.TestCase):
@@ -553,12 +552,12 @@ class TestComputeWriterResults(unittest.TestCase):
 
         ds1 = xr.DataArray(
             da.zeros((100, 200), chunks=50),
-            dims=('y', 'x'),
-            attrs={'name': 'test',
-                   'start_time': datetime(2018, 1, 1, 0, 0, 0)}
+            dims=("y", "x"),
+            attrs={"name": "test",
+                   "start_time": datetime(2018, 1, 1, 0, 0, 0)}
         )
         self.scn = Scene()
-        self.scn['test'] = ds1
+        self.scn["test"] = ds1
 
         # Temp dir
         self.base_dir = tempfile.mkdtemp()
@@ -578,89 +577,69 @@ class TestComputeWriterResults(unittest.TestCase):
     def test_simple_image(self):
         """Test writing to PNG file."""
         from satpy.writers import compute_writer_results
-        fname = os.path.join(self.base_dir, 'simple_image.png')
+        fname = os.path.join(self.base_dir, "simple_image.png")
         res = self.scn.save_datasets(filename=fname,
-                                     datasets=['test'],
-                                     writer='simple_image',
+                                     datasets=["test"],
+                                     writer="simple_image",
                                      compute=False)
         compute_writer_results([res])
-        self.assertTrue(os.path.isfile(fname))
+        assert os.path.isfile(fname)
 
     def test_geotiff(self):
         """Test writing to mitiff file."""
         from satpy.writers import compute_writer_results
-        fname = os.path.join(self.base_dir, 'geotiff.tif')
+        fname = os.path.join(self.base_dir, "geotiff.tif")
         res = self.scn.save_datasets(filename=fname,
-                                     datasets=['test'],
-                                     writer='geotiff', compute=False)
+                                     datasets=["test"],
+                                     writer="geotiff", compute=False)
         compute_writer_results([res])
-        self.assertTrue(os.path.isfile(fname))
-
-# FIXME: This reader needs more information than exist at the moment
-#    def test_mitiff(self):
-#        """Test writing to mitiff file"""
-#        fname = os.path.join(self.base_dir, 'mitiff.tif')
-#        res = self.scn.save_datasets(filename=fname,
-#                                     datasets=['test'],
-#                                     writer='mitiff')
-#        compute_writer_results([res])
-#        self.assertTrue(os.path.isfile(fname))
-
-# FIXME: This reader needs more information than exist at the moment
-#    def test_cf(self):
-#        """Test writing to NetCDF4 file"""
-#        fname = os.path.join(self.base_dir, 'cf.nc')
-#        res = self.scn.save_datasets(filename=fname,
-#                                     datasets=['test'],
-#                                     writer='cf')
-#        compute_writer_results([res])
-#        self.assertTrue(os.path.isfile(fname))
+        assert os.path.isfile(fname)
 
     def test_multiple_geotiff(self):
         """Test writing to mitiff file."""
         from satpy.writers import compute_writer_results
-        fname1 = os.path.join(self.base_dir, 'geotiff1.tif')
+        fname1 = os.path.join(self.base_dir, "geotiff1.tif")
         res1 = self.scn.save_datasets(filename=fname1,
-                                      datasets=['test'],
-                                      writer='geotiff', compute=False)
-        fname2 = os.path.join(self.base_dir, 'geotiff2.tif')
+                                      datasets=["test"],
+                                      writer="geotiff", compute=False)
+        fname2 = os.path.join(self.base_dir, "geotiff2.tif")
         res2 = self.scn.save_datasets(filename=fname2,
-                                      datasets=['test'],
-                                      writer='geotiff', compute=False)
+                                      datasets=["test"],
+                                      writer="geotiff", compute=False)
         compute_writer_results([res1, res2])
-        self.assertTrue(os.path.isfile(fname1))
-        self.assertTrue(os.path.isfile(fname2))
+        assert os.path.isfile(fname1)
+        assert os.path.isfile(fname2)
 
     def test_multiple_simple(self):
         """Test writing to geotiff files."""
         from satpy.writers import compute_writer_results
-        fname1 = os.path.join(self.base_dir, 'simple_image1.png')
+        fname1 = os.path.join(self.base_dir, "simple_image1.png")
         res1 = self.scn.save_datasets(filename=fname1,
-                                      datasets=['test'],
-                                      writer='simple_image', compute=False)
-        fname2 = os.path.join(self.base_dir, 'simple_image2.png')
+                                      datasets=["test"],
+                                      writer="simple_image", compute=False)
+        fname2 = os.path.join(self.base_dir, "simple_image2.png")
         res2 = self.scn.save_datasets(filename=fname2,
-                                      datasets=['test'],
-                                      writer='simple_image', compute=False)
+                                      datasets=["test"],
+                                      writer="simple_image", compute=False)
         compute_writer_results([res1, res2])
-        self.assertTrue(os.path.isfile(fname1))
-        self.assertTrue(os.path.isfile(fname2))
+        assert os.path.isfile(fname1)
+        assert os.path.isfile(fname2)
 
     def test_mixed(self):
         """Test writing to multiple mixed-type files."""
         from satpy.writers import compute_writer_results
-        fname1 = os.path.join(self.base_dir, 'simple_image3.png')
+        fname1 = os.path.join(self.base_dir, "simple_image3.png")
         res1 = self.scn.save_datasets(filename=fname1,
-                                      datasets=['test'],
-                                      writer='simple_image', compute=False)
-        fname2 = os.path.join(self.base_dir, 'geotiff3.tif')
+                                      datasets=["test"],
+                                      writer="simple_image", compute=False)
+        fname2 = os.path.join(self.base_dir, "geotiff3.tif")
         res2 = self.scn.save_datasets(filename=fname2,
-                                      datasets=['test'],
-                                      writer='geotiff', compute=False)
+                                      datasets=["test"],
+                                      writer="geotiff", compute=False)
         res3 = []
         compute_writer_results([res1, res2, res3])
-        self.assertTrue(os.path.isfile(fname1))
-        self.assertTrue(os.path.isfile(fname2))
+        assert os.path.isfile(fname1)
+        assert os.path.isfile(fname2)
 
 
 class TestBaseWriter:
@@ -675,18 +654,18 @@ class TestBaseWriter:
 
         ds1 = xr.DataArray(
             da.zeros((100, 200), chunks=50),
-            dims=('y', 'x'),
+            dims=("y", "x"),
             attrs={
-                'name': 'test',
-                'start_time': datetime(2018, 1, 1, 0, 0, 0),
-                'sensor': 'fake_sensor',
+                "name": "test",
+                "start_time": datetime(2018, 1, 1, 0, 0, 0),
+                "sensor": "fake_sensor",
             }
         )
         ds2 = ds1.copy()
-        ds2.attrs['sensor'] = {'fake_sensor1', 'fake_sensor2'}
+        ds2.attrs["sensor"] = {"fake_sensor1", "fake_sensor2"}
         self.scn = Scene()
-        self.scn['test'] = ds1
-        self.scn['test2'] = ds2
+        self.scn["test"] = ds1
+        self.scn["test2"] = ds2
 
         # Temp dir
         self.base_dir = tempfile.mkdtemp()
@@ -700,16 +679,16 @@ class TestBaseWriter:
 
     def test_save_dataset_static_filename(self):
         """Test saving a dataset with a static filename specified."""
-        self.scn.save_datasets(base_dir=self.base_dir, filename='geotiff.tif')
-        assert os.path.isfile(os.path.join(self.base_dir, 'geotiff.tif'))
+        self.scn.save_datasets(base_dir=self.base_dir, filename="geotiff.tif")
+        assert os.path.isfile(os.path.join(self.base_dir, "geotiff.tif"))
 
     @pytest.mark.parametrize(
-        ('fmt_fn', 'exp_fns'),
+        ("fmt_fn", "exp_fns"),
         [
-            ('geotiff_{name}_{start_time:%Y%m%d_%H%M%S}.tif',
-             ['geotiff_test_20180101_000000.tif', 'geotiff_test2_20180101_000000.tif']),
-            ('geotiff_{name}_{sensor}.tif',
-             ['geotiff_test_fake_sensor.tif', 'geotiff_test2_fake_sensor1-fake_sensor2.tif']),
+            ("geotiff_{name}_{start_time:%Y%m%d_%H%M%S}.tif",
+             ["geotiff_test_20180101_000000.tif", "geotiff_test2_20180101_000000.tif"]),
+            ("geotiff_{name}_{sensor}.tif",
+             ["geotiff_test_fake_sensor.tif", "geotiff_test2_fake_sensor1-fake_sensor2.tif"]),
         ]
     )
     def test_save_dataset_dynamic_filename(self, fmt_fn, exp_fns):
@@ -721,14 +700,14 @@ class TestBaseWriter:
 
     def test_save_dataset_dynamic_filename_with_dir(self):
         """Test saving a dataset with a format filename that includes a directory."""
-        fmt_fn = os.path.join('{start_time:%Y%m%d}', 'geotiff_{name}_{start_time:%Y%m%d_%H%M%S}.tif')
-        exp_fn = os.path.join('20180101', 'geotiff_test_20180101_000000.tif')
+        fmt_fn = os.path.join("{start_time:%Y%m%d}", "geotiff_{name}_{start_time:%Y%m%d_%H%M%S}.tif")
+        exp_fn = os.path.join("20180101", "geotiff_test_20180101_000000.tif")
         self.scn.save_datasets(base_dir=self.base_dir, filename=fmt_fn)
         assert os.path.isfile(os.path.join(self.base_dir, exp_fn))
 
         # change the filename pattern but keep the same directory
-        fmt_fn2 = os.path.join('{start_time:%Y%m%d}', 'geotiff_{name}_{start_time:%Y%m%d_%H}.tif')
-        exp_fn2 = os.path.join('20180101', 'geotiff_test_20180101_00.tif')
+        fmt_fn2 = os.path.join("{start_time:%Y%m%d}", "geotiff_{name}_{start_time:%Y%m%d_%H}.tif")
+        exp_fn2 = os.path.join("20180101", "geotiff_test_20180101_00.tif")
         self.scn.save_datasets(base_dir=self.base_dir, filename=fmt_fn2)
         assert os.path.isfile(os.path.join(self.base_dir, exp_fn2))
         # the original file should still exist
@@ -743,53 +722,53 @@ class TestOverlays(unittest.TestCase):
         from pyresample.geometry import AreaDefinition
         from trollimage.xrimage import XRImage
 
-        proj_dict = {'proj': 'lcc', 'datum': 'WGS84', 'ellps': 'WGS84',
-                     'lon_0': -95., 'lat_0': 25, 'lat_1': 25,
-                     'units': 'm', 'no_defs': True}
+        proj_dict = {"proj": "lcc", "datum": "WGS84", "ellps": "WGS84",
+                     "lon_0": -95., "lat_0": 25, "lat_1": 25,
+                     "units": "m", "no_defs": True}
         self.area_def = AreaDefinition(
-            'test', 'test', 'test', proj_dict,
+            "test", "test", "test", proj_dict,
             200, 400, (-1000., -1500., 1000., 1500.),
         )
         self.orig_rgb_img = XRImage(
             xr.DataArray(da.arange(75., chunks=10).reshape(3, 5, 5) / 75.,
-                         dims=('bands', 'y', 'x'),
-                         coords={'bands': ['R', 'G', 'B']},
-                         attrs={'name': 'test_ds', 'area': self.area_def})
+                         dims=("bands", "y", "x"),
+                         coords={"bands": ["R", "G", "B"]},
+                         attrs={"name": "test_ds", "area": self.area_def})
         )
         self.orig_l_img = XRImage(
             xr.DataArray(da.arange(25., chunks=10).reshape(5, 5) / 75.,
-                         dims=('y', 'x'),
-                         attrs={'name': 'test_ds', 'area': self.area_def})
+                         dims=("y", "x"),
+                         attrs={"name": "test_ds", "area": self.area_def})
         )
 
         self.decorate = {
-            'decorate': [
-                {'logo': {'logo_path': '', 'height': 143, 'bg': 'white', 'bg_opacity': 255}},
-                {'text': {
-                    'txt': 'TEST',
-                    'align': {'top_bottom': 'bottom', 'left_right': 'right'},
-                    'font': '',
-                    'font_size': 22,
-                    'height': 30,
-                    'bg': 'black',
-                    'bg_opacity': 255,
-                    'line': 'white'}},
-                {'scale': {
-                    'colormap': greys,
-                    'extend': False,
-                    'width': 1670, 'height': 110,
-                    'tick_marks': 5, 'minor_tick_marks': 1,
-                    'cursor': [0, 0], 'bg': 'white',
-                    'title': 'TEST TITLE OF SCALE',
-                    'fontsize': 110, 'align': 'cc'
+            "decorate": [
+                {"logo": {"logo_path": "", "height": 143, "bg": "white", "bg_opacity": 255}},
+                {"text": {
+                    "txt": "TEST",
+                    "align": {"top_bottom": "bottom", "left_right": "right"},
+                    "font": "",
+                    "font_size": 22,
+                    "height": 30,
+                    "bg": "black",
+                    "bg_opacity": 255,
+                    "line": "white"}},
+                {"scale": {
+                    "colormap": greys,
+                    "extend": False,
+                    "width": 1670, "height": 110,
+                    "tick_marks": 5, "minor_tick_marks": 1,
+                    "cursor": [0, 0], "bg": "white",
+                    "title": "TEST TITLE OF SCALE",
+                    "fontsize": 110, "align": "cc"
                 }}
             ]
         }
 
         import_mock = mock.MagicMock()
-        modules = {'pycoast': import_mock.pycoast,
-                   'pydecorate': import_mock.pydecorate}
-        self.module_patcher = mock.patch.dict('sys.modules', modules)
+        modules = {"pycoast": import_mock.pycoast,
+                   "pydecorate": import_mock.pydecorate}
+        self.module_patcher = mock.patch.dict("sys.modules", modules)
         self.module_patcher.start()
 
     def tearDown(self):
@@ -801,21 +780,21 @@ class TestOverlays(unittest.TestCase):
         from pycoast import ContourWriterAGG
 
         from satpy.writers import _burn_overlay, add_overlay
-        coast_dir = '/path/to/coast/data'
+        coast_dir = "/path/to/coast/data"
         with mock.patch.object(self.orig_rgb_img, "apply_pil") as apply_pil:
             apply_pil.return_value = self.orig_rgb_img
             new_img = add_overlay(self.orig_rgb_img, self.area_def, coast_dir, fill_value=0)
-            self.assertEqual(self.orig_rgb_img.mode, new_img.mode)
+            assert self.orig_rgb_img.mode == new_img.mode
             new_img = add_overlay(self.orig_rgb_img, self.area_def, coast_dir)
-            self.assertEqual(self.orig_rgb_img.mode + 'A', new_img.mode)
+            assert self.orig_rgb_img.mode + "A" == new_img.mode
 
             with mock.patch.object(self.orig_rgb_img, "convert") as convert:
                 convert.return_value = self.orig_rgb_img
-                overlays = {'coasts': {'outline': 'red'}}
+                overlays = {"coasts": {"outline": "red"}}
                 new_img = add_overlay(self.orig_rgb_img, self.area_def, coast_dir,
                                       overlays=overlays, fill_value=0)
                 pil_args = None
-                pil_kwargs = {'fill_value': 0}
+                pil_kwargs = {"fill_value": 0}
                 fun_args = (self.orig_rgb_img.data.area, ContourWriterAGG.return_value, overlays)
                 fun_kwargs = None
                 apply_pil.assert_called_with(_burn_overlay, self.orig_rgb_img.mode,
@@ -824,11 +803,11 @@ class TestOverlays(unittest.TestCase):
 
                 # test legacy call
 
-                grid = {'minor_is_tick': True}
-                color = 'red'
-                expected_overlays = {'coasts': {'outline': color, 'width': 0.5, 'level': 1},
-                                     'borders': {'outline': color, 'width': 0.5, 'level': 1},
-                                     'grid': grid}
+                grid = {"minor_is_tick": True}
+                color = "red"
+                expected_overlays = {"coasts": {"outline": color, "width": 0.5, "level": 1},
+                                     "borders": {"outline": color, "width": 0.5, "level": 1},
+                                     "grid": grid}
                 with warnings.catch_warnings(record=True) as wns:
                     warnings.simplefilter("always")
                     new_img = add_overlay(self.orig_rgb_img, self.area_def, coast_dir,
@@ -838,7 +817,7 @@ class TestOverlays(unittest.TestCase):
                     assert "deprecated" in str(wns[0].message)
 
                 pil_args = None
-                pil_kwargs = {'fill_value': 0}
+                pil_kwargs = {"fill_value": 0}
                 fun_args = (self.orig_rgb_img.data.area, ContourWriterAGG.return_value, expected_overlays)
                 fun_kwargs = None
                 apply_pil.assert_called_with(_burn_overlay, self.orig_rgb_img.mode,
@@ -848,22 +827,22 @@ class TestOverlays(unittest.TestCase):
     def test_add_overlay_basic_l(self):
         """Test basic add_overlay usage with L data."""
         from satpy.writers import add_overlay
-        new_img = add_overlay(self.orig_l_img, self.area_def, '', fill_value=0)
-        self.assertEqual('RGB', new_img.mode)
-        new_img = add_overlay(self.orig_l_img, self.area_def, '')
-        self.assertEqual('RGBA', new_img.mode)
+        new_img = add_overlay(self.orig_l_img, self.area_def, "", fill_value=0)
+        assert "RGB" == new_img.mode
+        new_img = add_overlay(self.orig_l_img, self.area_def, "")
+        assert "RGBA" == new_img.mode
 
     def test_add_decorate_basic_rgb(self):
         """Test basic add_decorate usage with RGB data."""
         from satpy.writers import add_decorate
         new_img = add_decorate(self.orig_rgb_img, **self.decorate)
-        self.assertEqual('RGBA', new_img.mode)
+        assert "RGBA" == new_img.mode
 
     def test_add_decorate_basic_l(self):
         """Test basic add_decorate usage with L data."""
         from satpy.writers import add_decorate
         new_img = add_decorate(self.orig_l_img, **self.decorate)
-        self.assertEqual('RGBA', new_img.mode)
+        assert "RGBA" == new_img.mode
 
 
 def test_group_results_by_output_file(tmp_path):
@@ -876,9 +855,8 @@ def test_group_results_by_output_file(tmp_path):
     """
     from pyresample import create_area_def
 
+    from satpy.tests.utils import make_fake_scene
     from satpy.writers import group_results_by_output_file
-
-    from .utils import make_fake_scene
     x = 10
     fake_area = create_area_def("sargasso", 4326, resolution=1, width=x, height=x, center=(0, 0))
     fake_scene = make_fake_scene(
